@@ -1004,8 +1004,10 @@ def perform_adjustment(
 
         
         guide_count_posterior_LFC_samples_normalized_list: List[List[float]] = shrinkage_result.guide_count_posterior_LFC_samples_normalized_list 
+
+        guide_count_LFC_samples_normalized_list: List[List[float]] = shrinkage_result.guide_count_LFC_samples_normalized_list
         
-        guide_count_posterior_LFC_samples_normalized_list_rescaled = np.asarray([np.exp(guide_count_posterior_LFC_samples_normalized_list[rep_i]) * ((each_guide.sample_population_normalized_count_reps[rep_i] + each_guide.control_population_normalized_count_reps[rep_i]) * negative_control_guide_control_population_total_normalized_counts_reps[rep_i]) / ((negative_control_guide_sample_population_total_normalized_counts_reps[rep_i] + negative_control_guide_control_population_total_normalized_counts_reps[rep_i]) * each_guide.control_population_normalized_count_reps[rep_i]) for rep_i in replicate_indices])
+        guide_count_posterior_LFC_samples_normalized_list_rescaled = np.asarray([np.log(np.exp(guide_count_posterior_LFC_samples_normalized_list[rep_i]) * (((each_guide.sample_population_normalized_count_reps[rep_i] + each_guide.control_population_normalized_count_reps[rep_i]) * negative_control_guide_control_population_total_normalized_counts_reps[rep_i]) / ((negative_control_guide_sample_population_total_normalized_counts_reps[rep_i] + negative_control_guide_control_population_total_normalized_counts_reps[rep_i]) * each_guide.control_population_normalized_count_reps[rep_i]))) for rep_i in replicate_indices])
 
         guide_count_posterior_LFC_samples_normalized_average = np.mean(guide_count_posterior_LFC_samples_normalized_list, axis=0)
         guide_count_posterior_LFC_samples_normalized_rescaled_average =  np.mean(guide_count_posterior_LFC_samples_normalized_list_rescaled, axis=0)
@@ -1110,6 +1112,8 @@ def perform_adjustment(
         each_guide.guide_count_posterior_LFC_samples_normalized_list_rescaled = guide_count_posterior_LFC_samples_normalized_list_rescaled
         each_guide.guide_count_posterior_LFC_samples_normalized_average_rescaled = guide_count_posterior_LFC_samples_normalized_rescaled_average
 
+        each_guide.guide_count_LFC_samples_normalized_list = guide_count_LFC_samples_normalized_list
+
         return each_guide
 
     # Perform final model inference:
